#!/bin/bash
#
# This script assumes that you python-pip is installed.
# Further, this will fail miserably if you are running this outside of
# of the Juju Quickstart images (https://cloud-images.ubuntu.com/vagrant)

legacy_juju=0
(dpkg-query -s juju-local >> /dev/null ) || legacy_juju=1

_run_cmd() {
    [ "${legacy_juju}" -eq 0 ] &&
        su vagrant -c "${@}" ||
       ${@}
}

_juju() {
    _run_cmd "juju ${@}"
}

my_dir=$(dirname ${0})

cp -au /home/vagrant/{.ssh,.juju} /root
chown root: /root

# Bootstrap Juju
echo "Bootstrapping Juju..."
_juju bootstrap

# Launch the GUI
echo "Taking a nap to let state server come up..."
sleep 60
_juju "deploy juju-gui"

# Install the pip requirements
echo "Setting up Juju GUI dependencies...this may take a minute."
echo "You can find the log in /var/log/juju-setup.log"

(pip install tornado
pip install flake8
pip install futures
pip install concurrent
pip install jujuclient

# Check out the Juju Redirect server
bzr branch lp:~juju-gui/juju-gui/redirect-server /tmp/redirect-server >> /dev/null

# Install it
python /tmp/redirect-server/setup.py install

# Make the vagrant user able to use the stuff
rsync -a /root/.juju /home/vagrant
chown -R vagrant: /home/vagrant/.juju

# Install the upstart job
cp ${my_dir}/redirect.py /root
chmod 0755 /root/redirect.py
cp ${my_dir}/juju-gui.conf /etc/init/juju-gui.conf
) >> /var/log/juju-setup.log

echo "Taking a nap to let Juju Gui get setup"
sleep 60

_juju "expose juju-gui"
python /root/redirect.py
_juju "set juju-gui secure='false'"

# Start it all up
start juju-gui
sleep 5
status juju-gui
